{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/expected_md5"
                },
                {
                    "type": "File",
                    "id": "#main/input_file"
                }
            ],
            "steps": [
                {
                    "run": "#md5sum-checker.cwl",
                    "in": [
                        {
                            "source": "#main/expected_md5",
                            "id": "#main/checker/expected_md5"
                        },
                        {
                            "source": "#main/md5sum/output_file",
                            "id": "#main/checker/input_file"
                        }
                    ],
                    "out": [
                        "#main/checker/results_file"
                    ],
                    "id": "#main/checker"
                },
                {
                    "run": "#md5sum-workflow.cwl",
                    "in": [
                        {
                            "source": "#main/input_file",
                            "id": "#main/md5sum/input_file"
                        }
                    ],
                    "out": [
                        "#main/md5sum/output_file"
                    ],
                    "id": "#main/md5sum"
                }
            ],
            "doc": "This demonstrates how to wrap a \"real\" tool with a checker workflow that runs both the tool and a tool that performs verification of results\n",
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/checker/results_file",
                    "id": "#main/workflow_output_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#md5sum-checker.cwl",
            "label": "A tool that checks the md5sum workflow",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/agduncan94/checker-md5sum"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 1024,
                    "outdirMin": 512000
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--md5"
                    },
                    "id": "#md5sum-checker.cwl/Md5sumWorkflowChecker/expected_md5"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--input-file"
                    },
                    "doc": "The file that contains an md5sum.",
                    "id": "#md5sum-checker.cwl/Md5sumWorkflowChecker/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "log.txt"
                    },
                    "doc": "A text log file that contains more details.",
                    "id": "#md5sum-checker.cwl/Md5sumWorkflowChecker/log_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results.json"
                    },
                    "doc": "A json file that contains the result of the test.",
                    "id": "#md5sum-checker.cwl/Md5sumWorkflowChecker/results_file"
                }
            ],
            "baseCommand": [
                "/bin/check_md5sum"
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#md5sum-tool.cwl",
            "label": "Simple md5sum tool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/agduncan94/my-md5sum"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 1024,
                    "outdirMin": 512
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "The file that will have its md5sum calculated.",
                    "id": "#md5sum-tool.cwl/Md5sum/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/data_3671",
                    "outputBinding": {
                        "glob": "md5sum.txt"
                    },
                    "doc": "A text file that contains a single line that is the md5sum of the input file.",
                    "id": "#md5sum-tool.cwl/Md5sum/output_file"
                }
            ],
            "baseCommand": [
                "/bin/my_md5sum"
            ]
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#md5sum-workflow.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#md5sum-workflow.cwl/md5sum/output_file",
                    "id": "#md5sum-workflow.cwl/output_file"
                }
            ],
            "steps": [
                {
                    "run": "#md5sum-tool.cwl",
                    "in": [
                        {
                            "source": "#md5sum-workflow.cwl/input_file",
                            "id": "#md5sum-workflow.cwl/md5sum/input_file"
                        }
                    ],
                    "out": [
                        "#md5sum-workflow.cwl/md5sum/output_file"
                    ],
                    "id": "#md5sum-workflow.cwl/md5sum"
                }
            ],
            "id": "#md5sum-workflow.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
